library(Rlabkey)

#' Check and display LabKey session status
#'
#' This function retrieves and displays the current user's LabKey session status, including
#' the user's name, connection status, ID, and email. It outputs this information in a
#' human-readable format.
#'
#' @return This function does not return any value. It prints the session status to the console.
#' @note This function assumes that the LabKey session is already initialized and accessible within RLabkey Server.
#' @export
status <- function() {
  tryCatch({
    # Retrieve the current user's session info
    current_user_info <- labkey.whoAmI(baseUrl = NULL)

    # Display session status
    message("LabKey session status:")
    message(paste("\n Name:", current_user_info$displayName))
    message(paste("\n Connected:", current_user_info$success))
    message(paste("\n ID:", current_user_info$id))
    message(paste("\n Email:", current_user_info$email))

  }, error = function(e) {
    message("An error occurred while fetching LabKey session status: ", conditionMessage(e))
  })
}
